@@ -15,11 +15,21 @@ class SaveContent(BaseModel):
     type: str
 
 
+class CreateContent(BaseModel):
+    ext: Optional[str]
+    path: str
+    type: str
+
+
+class RenameContent(BaseModel):
+    path: str
+
+
 class Content(BaseModel):
     name: str
     path: str
     last_modified: Optional[str]
-    created: str
+    created: Optional[str]
     content: Optional[Union[str, List[Dict]]]
     format: Optional[str]
     mimetype: Optional[str]
